@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: edit_entry.php,v 1.91.2.1 2005/08/08 23:30:57 cknudsen Exp $
+ * $Id: edit_entry.php,v 1.91.2.2 2006/03/15 03:14:54 umcesrjones Exp $
  *
  * Description:
  * Presents page to edit/add an event
@@ -418,7 +418,7 @@ if ( $TIME_FORMAT == "12" ) {
 
 <?php
   $dur_h = (int)( $duration / 60 );
-  $dur_m = $duration - ( $dur_h * 60 );
+  $dur_m = $duration % 60;
 
 if ($GLOBALS['TIMED_EVT_LEN'] != 'E') { ?>
    </td></tr>
@@ -453,7 +453,7 @@ if ( $id ) {
   // Add duration
   $endhour = $t_h12 + $dur_h;
   $endminute = $minute + $dur_m;
-  $endhour = $endhour + ( $endminute / 60 );
+  $endhour = $endhour + (int)( $endminute / 60 );
   $endminute %= 60;
 
   if ( $TIME_FORMAT == "12" ) {
