@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: edit_report.php,v 1.24.2.1 2005/10/14 18:22:35 cknudsen Exp $
+ * $Id: edit_report.php,v 1.24.2.2 2006/01/05 14:22:34 umcesrjones Exp $
  *
  * Page Description:
  * This page will present the HTML form to add or edit a report.
@@ -106,7 +106,7 @@ $event_template = "<dt>\${name}</dt>\n<dd>" .
   "<b>" . translate ( "Time" ) . ":</b> \${time}<br />\n" .
   "\${description}</dd>\n";
 
-if ( empty ( $error ) && $report_id > 0 ) {
+if ( empty ( $error ) && $report_id >= 0 ) {
   $sql = "SELECT cal_login, cal_report_id, cal_is_global, " .
     "cal_report_type, cal_include_header, cal_report_name, " .
     "cal_time_range, cal_user, cal_allow_nav, cal_cat_id, " .
