@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: edit_report_handler.php,v 1.11 2005/04/13 14:14:14 cknudsen Exp $
+ * $Id: edit_report_handler.php,v 1.11.2.1 2006/01/05 14:22:34 umcesrjones Exp $
  *
  * Page Description:
  *	This page will handle the form submission from edit_report.php
@@ -157,7 +157,7 @@ if ( empty ( $error ) ) {
   }
 
   $names[] = "cal_time_range";
-  $values[] = ( empty ( $time_range ) ? 11 : $time_range );
+  $values[] = ( ! isset ( $time_range ) ? 11 : $time_range );
 
   $names[] = "cal_cat_id";
   $values[] = ( empty ( $cat_id ) ? "NULL" : $cat_id );
