@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: report.php,v 1.27.2.3 2005/10/14 18:38:59 cknudsen Exp $
+ * $Id: report.php,v 1.27.2.4 2006/01/05 14:22:34 umcesrjones Exp $
  *
  * Page Description:
  * This page will either list all reports available to the current
@@ -325,7 +325,7 @@ if ( empty ( $offset ) || empty ( $report_allow_nav ) ||
 }
 
 // Set time range based on cal_time_range field.
-if ( empty ( $report_time_range ) ) {
+if ( ! isset ( $report_time_range ) ) {
   // manage reports
 } else if ( $report_time_range >= 0 && $report_time_range < 10 ) {
   $today = mktime ( 3, 0, 0, date ( "m" ), date ( "d" ), date ( "Y" ) );
