@@ -1,14 +1,14 @@
 /*
  * Description:
- *	This file is used to create all tables used by WebCalendar and
- *	initialize some of those tables with the required data.
+ * This file is used to create all tables used by WebCalendar and
+ * initialize some of those tables with the required data.
  *
- *	The comments in the table definitions will be parsed to
- *	generate a document (in HTML) that describes these tables.
+ * The comments in the table definitions will be parsed to
+ * generate a document (in HTML) that describes these tables.
  *
  * History:
- *	21-Oct-2002	Added this file header and additional comments
- *			below.
+ * 21-Oct-2002 Added this file header and additional comments
+ *   below.
  */
 
 /*
@@ -282,6 +282,8 @@ CREATE TABLE webcal_view (
   cal_name VARCHAR(50) NOT NULL,
   /* "W" for week view, "D" for day view, "M" for month view */
   cal_view_type CHAR(1),
+  /* is this a global view (can it be accessed by other users) ('Y' or 'N') */
+  cal_is_global CHAR(1) DEFAULT 'N' NOT NULL,
   PRIMARY KEY ( cal_view_id )
 );
 
@@ -343,29 +345,29 @@ INSERT INTO webcal_config ( cal_setting, cal_value )
 INSERT INTO webcal_config ( cal_setting, cal_value )
   VALUES ( 'allow_color_customization', 'Y' );
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'BGCOLOR', '#C0C0C0' );
+  VALUES ('BGCOLOR','#FFFFFF');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'TEXTCOLOR', '#000000' );
+  VALUES ('TEXTCOLOR','#000000');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'H2COLOR', '#000000' );
+  VALUES ('H2COLOR','#000000');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'CELLBG', '#C0C0C0' );
+  VALUES ('CELLBG','#C0C0C0');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'WEEKENDBG', '#D0D0D0' );
+  VALUES ('WEEKENDBG','#D0D0D0');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'TABLEBG', '#000000' );
+  VALUES ('TABLEBG','#000000');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'THBG', '#FFFFFF' );
+  VALUES ('THBG','#FFFFFF');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'THFG', '#000000' );
+  VALUES ('THFG','#000000');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'POPUP_FG', '#000000' );
+  VALUES ('POPUP_FG','#000000');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'POPUP_BG', '#FFFFFF' );
+  VALUES ('POPUP_BG','#FFFFFF');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'TODAYCELLBG', '#E0E0E0' );
+  VALUES ('TODAYCELLBG','#FFFF33');
 INSERT INTO webcal_config ( cal_setting, cal_value )
-  VALUES ( 'STARTVIEW', 'week' );
+  VALUES ( 'STARTVIEW', 'week.php' );
 INSERT INTO webcal_config ( cal_setting, cal_value )
   VALUES ( 'WEEK_START', '0' );
 INSERT INTO webcal_config ( cal_setting, cal_value )
@@ -390,6 +392,73 @@ INSERT INTO webcal_config ( cal_setting, cal_value )
   VALUES ( 'EMAIL_EVENT_DELETED', 'Y' );
 INSERT INTO webcal_config ( cal_setting, cal_value )
   VALUES ( 'EMAIL_EVENT_REJECTED', 'Y' );
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('auto_refresh', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('nonuser_enabled', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('allow_html_description', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('reports_enabled', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('DISPLAY_WEEKENDS', 'Y');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('DISPLAY_DESC_PRINT_DAY', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('DATE_FORMAT', '__month__ __dd__, __yyyy__');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('TIME_SLOTS', '12');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('TIMED_EVT_LEN', 'D');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('PUBLISH_ENABLED', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('DATE_FORMAT_MY', '__month__ __yyyy__');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('DATE_FORMAT_MD', '__month__ __dd__');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('CUSTOM_SCRIPT', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('CUSTOM_HEADER', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('CUSTOM_TRAILER', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('bold_days_in_year', 'Y');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('site_extras_in_popup', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('add_link_in_views', 'Y');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('allow_conflict_override', 'Y');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('limit_appts', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('limit_appts_number', '6');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('public_access', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('public_access_default_visible', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('public_access_default_selected', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('public_access_others', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('public_access_can_add', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('public_access_add_needs_approval', 'Y');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('public_access_view_part', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('nonuser_at_top', 'Y');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('allow_external_users', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('external_notifications', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('external_reminders', 'N');
+INSERT INTO webcal_config ( cal_setting, cal_value )
+  VALUES ('enable_gradients', 'N');
+
 
 /*
  * Activity log for an event.
@@ -490,9 +559,9 @@ CREATE TABLE webcal_import_data (
   cal_id INT NOT NULL,
   /* user login */
   cal_login VARCHAR(25) NOT NULL,
-  /* type of import: 'palm', 'vcal', etc. */
+  /* type of import: 'palm', 'vcal', 'ical' or 'publish' */
   cal_import_type VARCHAR(15) NOT NULL,
-  /* external id used in external calendar system */
+  /* external id used in external calendar system (for example, UID in iCal) */
   cal_external_id VARCHAR(200) NULL,
   PRIMARY KEY  ( cal_id, cal_login )
 );
