@@ -1,4 +1,17 @@
 <?php
+/*
+ * $Id: view_entry.php,v 1.68.2.2 2005/08/10 14:35:15 cknudsen Exp $
+ *
+ * Description:
+ * Presents page to view an event with links to edit, delete
+ * confirm, copy, add event
+ *
+ * Input Parameters:
+ * id (*) - cal_id of requested event
+ * date  - yyyymmdd format of requested event
+ * user  - user to display
+ * (*) required field
+ */
 include_once 'includes/init.php';
 include_once 'includes/site_extras.php';
 
@@ -6,97 +19,131 @@ include_once 'includes/site_extras.php';
 $can_view = false;
 $is_my_event = false;
 
-if ( $is_admin || $is_nonuser_admin || $is_assistant )
+if ( $is_admin || $is_nonuser_admin || $is_assistant ) {
   $can_view = true;
+} 
 
-// is this user a participant or the creator of the event?
-$sql = "SELECT webcal_entry.cal_id FROM webcal_entry, " .
-  "webcal_entry_user WHERE webcal_entry.cal_id = " .
-  "webcal_entry_user.cal_id AND webcal_entry.cal_id = $id " .
-  "AND (webcal_entry.cal_create_by = '$login' " .
-  "OR webcal_entry_user.cal_login = '$login')";
-$res = dbi_query ( $sql );
-if ( $res ) {
-  $row = dbi_fetch_row ( $res );
-  if ( $row && $row[0] > 0 ) {
+$error = '';
+
+if ( empty ( $id ) || $id <= 0 || ! is_numeric ( $id ) ) {
+  $error = translate ( "Invalid entry id" ) . "."; 
+}
+
+if ( empty ( $error ) ) {
+  // is this user a participant or the creator of the event?
+  $sql = "SELECT webcal_entry.cal_id FROM webcal_entry, " .
+    "webcal_entry_user WHERE webcal_entry.cal_id = " .
+    "webcal_entry_user.cal_id AND webcal_entry.cal_id = $id " .
+    "AND (webcal_entry.cal_create_by = '$login' " .
+    "OR webcal_entry_user.cal_login = '$login')";
+  $res = dbi_query ( $sql );
+  if ( $res ) {
+    $row = dbi_fetch_row ( $res );
+    if ( $row && $row[0] > 0 ) {
+      $can_view = true;
+      $is_my_event = true;
+    }
+    dbi_free_result ( $res );
+  }
+
+  if ( ($login != "__public__") && ($public_access_others == "Y") ) {
     $can_view = true;
-    $is_my_event = true;
   }
-  dbi_free_result ( $res );
-}
 
-if ( ($login != "__public__") && ($public_access_others == "Y") ) {
-  $can_view = true;
-}
-
-if ( ! $can_view ) {
-  $check_group = false;
-  // if not a participant in the event, must be allowed to look at
-  // other user's calendar.
-  if ( $login == "__public__" ) {
-    if ( $public_access_others == "Y" )
-      $check_group = true;
-  }
-  else {
-    if ( $allow_view_other == "Y" )
-      $check_group = true;
-  }
-  // If $check_group is true now, it means this user can look at the
-  // event only if they are in the same group as some of the people in
-  // the event.
-  // This gets kind of tricky.  If there is a participant from a different
-  // group, do we still show it?  For now, the answer is no.
-  // This could be configurable somehow, but how many lines of text would
-  // it need in the admin page to describe this scenario?  Would confuse
-  // 99.9% of users.
-  // In summary, make sure at least one event participant is in one of
-  // this user's groups.
-  $my_users = get_my_users ();
-  if ( is_array ( $my_users ) ) {
-    $sql = "SELECT webcal_entry.cal_id FROM webcal_entry, " .
-      "webcal_entry_user WHERE webcal_entry.cal_id = " .
-      "webcal_entry_user.cal_id AND webcal_entry.cal_id = $id " .
-      "AND webcal_entry_user.cal_login IN ( ";
-    for ( $i = 0; $i < count ( $my_users ); $i++ ) {
-      if ( $i > 0 )
-        $sql .= ", ";
-      $sql .= "'" . $my_users[$i]['cal_login'] . "'";
+  if ( ! $can_view ) {
+    $check_group = false;
+    // if not a participant in the event, must be allowed to look at
+    // other user's calendar.
+    if ( $login == "__public__" ) {
+      if ( $public_access_others == "Y" ) {
+        $check_group = true;
+      }
+    } else {
+      if ( $allow_view_other == "Y" ) {
+        $check_group = true;
+      }
     }
-    $sql .= " )";
-    $res = dbi_query ( $sql );
-    if ( $res ) {
-      $row = dbi_fetch_row ( $res );
-      if ( $row && $row[0] > 0 )
-        $can_view = true;
-      dbi_free_result ( $res );
+    // If $check_group is true now, it means this user can look at the
+    // event only if they are in the same group as some of the people in
+    // the event.
+    // This gets kind of tricky.  If there is a participant from a different
+    // group, do we still show it?  For now, the answer is no.
+    // This could be configurable somehow, but how many lines of text would
+    // it need in the admin page to describe this scenario?  Would confuse
+    // 99.9% of users.
+    // In summary, make sure at least one event participant is in one of
+    // this user's groups.
+    $my_users = get_my_users ();
+    if ( is_array ( $my_users ) ) {
+      $sql = "SELECT webcal_entry.cal_id FROM webcal_entry, " .
+        "webcal_entry_user WHERE webcal_entry.cal_id = " .
+        "webcal_entry_user.cal_id AND webcal_entry.cal_id = $id " .
+        "AND webcal_entry_user.cal_login IN ( ";
+      for ( $i = 0; $i < count ( $my_users ); $i++ ) {
+        if ( $i > 0 ) {
+          $sql .= ", ";
+        }
+        $sql .= "'" . $my_users[$i]['cal_login'] . "'";
+        }
+      $sql .= " )";
+      $res = dbi_query ( $sql );
+      if ( $res ) {
+        $row = dbi_fetch_row ( $res );
+        if ( $row && $row[0] > 0 ) {
+          $can_view = true;
+        }
+        dbi_free_result ( $res );
+      }
+    }
+    // If we didn't indicate we need to check groups, then this user
+    // can't view this event.
+    if ( ! $check_group ) {
+      $can_view = false;
     }
   }
-  // If we didn't indicate we need to check groups, then this user
-  // can't view this event.
-  if ( ! $check_group )
-    $can_view = false;
 }
 
-if ( ! $can_view ) {
+// If they still cannot view, make sure they are not looking at a nonuser
+// calendar event where the nonuser is the _only_ participant.
+if ( empty ( $error ) && ! $can_view && ! empty ( $nonuser_enabled ) &&
+  $nonuser_enabled == 'Y' ) {
+  $nonusers = get_nonuser_cals ();
+  $nonuser_lookup = array ();
+  for ( $i = 0; $i < count ( $nonusers ); $i++ ) {
+    $nonuser_lookup[$nonusers[$i]['cal_login']] = 1;
+  }
+  $sql = "SELECT cal_login FROM webcal_entry_user " .
+    "WHERE cal_id = $id AND cal_status in ('A','W')";
+  $res = dbi_query ( $sql );
+  $found_nonuser_cal = false;
+  $found_reg_user = false;
+  if ( $res ) {
+    while ( $row = dbi_fetch_row ( $res ) ) {
+      if ( ! empty ( $nonuser_lookup[$row[0]] ) ) {
+        $found_nonuser_cal = true;
+      } else {
+        $found_reg_user = true;
+      }
+    }
+    dbi_free_result ( $res );
+  }
+  // Does this event contain only nonuser calendars as participants?
+  // If so, then grant access.
+  if ( $found_nonuser_cal && ! $found_reg_user ) {
+    $can_view = true;
+  }
+}
+  
+if ( empty ( $error ) && ! $can_view ) {
   $error = translate ( "You are not authorized" );
 }
 
-// copied from edit_entry_handler (functions.php?)
-function add_duration ( $time, $duration ) {
-  $hour = (int) ( $time / 10000 );
-  $min = ( $time / 100 ) % 100;
-  $minutes = $hour * 60 + $min + $duration;
-  $h = $minutes / 60;
-  $m = $minutes % 60;
-  $ret = sprintf ( "%d%02d00", $h, $m );
-  //echo "add_duration ( $time, $duration ) = $ret <br />";
-  return $ret;
-}
-
-if ( ! empty ( $year ) )
+if ( ! empty ( $year ) ) {
   $thisyear = $year;
-if ( ! empty ( $month ) )
+}
+if ( ! empty ( $month ) ) {
   $thismonth = $month;
+}
 $pri[1] = translate("Low");
 $pri[2] = translate("Medium");
 $pri[3] = translate("High");
@@ -106,7 +153,7 @@ $unapproved = FALSE;
 // Make sure this is not a continuation event.
 // If it is, redirect the user to the original event.
 $ext_id = -1;
-if ( $id > 0 ) {
+if ( empty ( $error ) ) {
   $res = dbi_query ( "SELECT cal_ext_for_id FROM webcal_entry " .
     "WHERE cal_id = $id" );
   if ( $res ) {
@@ -120,37 +167,45 @@ if ( $id > 0 ) {
 }
 if ( $ext_id > 0 ) {
   $url = "view_entry.php?id=$ext_id";
-  if ( $date != "" )
+  if ( $date != "" ) {
     $url .= "&amp;date=$date";
-  if ( $user != "" )
+  }
+  if ( $user != "" ) {
     $url .= "&amp;user=$user";
-  if ( $cat_id != "" )
+  }
+  if ( $cat_id != "" ) {
     $url .= "&amp;cat_id=$cat_id";
+  }
   do_redirect ( $url );
 }
 
 print_header();
 
-if ( $id < 1 ) {
-  echo translate("Invalid entry id") . ".";
+if ( ! empty ( $error ) ) {
+  echo "<h2>" . translate ( "Error" ) .
+    "</h2>\n" . $error;
+  print_trailer ();
+  echo "</body>\n</html>";
   exit;
 }
-
 // Try to determine the event status.
 $event_status = "";
 
-if ( $login != $user ) {
+if ( ! empty ( $user ) && $login != $user ) {
   // If viewing another user's calendar, check the status of the
   // event on their calendar (to see if it's deleted).
   $sql = "SELECT cal_status FROM webcal_entry_user " .
     "WHERE cal_login = '$user' AND cal_id = $id";
   $res = dbi_query ( $sql );
   if ( $res ) {
-    if ( $row = dbi_fetch_row ( $res ) )
+    if ( $row = dbi_fetch_row ( $res ) ) {
       $event_status = $row[0];
+    }
     dbi_free_result ( $res );
   }
 } else {
+  // We are viewing event on user's own calendar, so check the
+  // status on their own calendar.
   $sql = "SELECT cal_id, cal_status FROM webcal_entry_user " .
     "WHERE cal_login = '$login' AND cal_id = $id";
   $res = dbi_query ( $sql );
@@ -170,11 +225,12 @@ if ( $login != $user ) {
 // calendar.
 if ( empty ( $event_status ) ) {
   $sql = "SELECT cal_status FROM webcal_entry_user " .
-    "WHERE cal_status != 'D' ORDER BY cal_status";
+    "WHERE cal_status <> 'D' ORDER BY cal_status";
   $res = dbi_query ( $sql );
   if ( $res ) {
-    if ( $row = dbi_fetch_row ( $res ) )
+    if ( $row = dbi_fetch_row ( $res ) ) {
       $event_status = $row[0];
+    }
     dbi_free_result ( $res );
   }
 }
@@ -182,8 +238,8 @@ if ( empty ( $event_status ) ) {
 // If we have no event status yet, it must have been deleted.
 if ( ( empty ( $event_status ) && ! $is_admin ) || ! $can_view ) {
   echo "<h2>" . 
-	translate("Error") . "</h2>" . 
-	translate("You are not authorized") . ".\n";
+    translate("Error") . "</h2>" . 
+    translate("You are not authorized") . ".\n";
   print_trailer ();
   echo "</body>\n</html>";
   exit;
@@ -193,21 +249,32 @@ if ( ( empty ( $event_status ) && ! $is_admin ) || ! $can_view ) {
 // Load event info now.
 $sql = "SELECT cal_create_by, cal_date, cal_time, cal_mod_date, " .
   "cal_mod_time, cal_duration, cal_priority, cal_type, cal_access, " .
-  "cal_name, cal_description FROM webcal_entry WHERE cal_id = " . $id;
+  "cal_name, cal_description FROM webcal_entry WHERE cal_id = $id";
 $res = dbi_query ( $sql );
 if ( ! $res ) {
   echo translate("Invalid entry id") . ": $id";
   exit;
 }
+
 $row = dbi_fetch_row ( $res );
-$create_by = $row[0];
-$orig_date = $row[1];
-$event_time = $row[2];
-$name = $row[9];
-$description = $row[10];
+if ( $row ) { 
+  $create_by = $row[0];
+  $orig_date = $row[1];
+  $event_time = $row[2];
+  $name = $row[9];
+  $description = $row[10];
+} else {
+  echo "<h2>" . 
+    translate("Error") . "</h2>" . 
+    translate("Invalid entry id") . ".\n";
+  print_trailer ();
+  echo "</body>\n</html>";
+  exit;
+}
 
 // Timezone Adjustments
-if ( $event_time >= 0 && $TZ_OFFSET != 0 ) { // -1 = no time specified
+if ( $event_time >= 0 && ! empty ( $TZ_OFFSET )  && $TZ_OFFSET != 0 ) { 
+  // -1 = no time specified
   $adjusted_time = $event_time + $TZ_OFFSET * 10000;
   $year = substr($row[1],0,4);
   $month = substr($row[1],4,2);
@@ -234,7 +301,7 @@ $thisdow = date ( "w", $thistime );
 $subject = translate($application_name) . ": " . $name;
 // Remove the '"' character since it causes some mailers to barf
 $subject = str_replace ( "\"", "", $subject );
-$subject = htmlentities ( $subject );
+$subject = htmlspecialchars ( $subject );
 
 $event_repeats = false;
 // build info string for repeating events and end date
@@ -264,8 +331,9 @@ if ( $res ) {
         case 4: $rep_str .= translate("4th"); break;
         case 5: $rep_str .= translate("5th"); break;
         case 12: if ( $cal_type == 'monthlyByDay' ||
-          $cal_type == 'monthlyByDayR' )
-          break;
+                   $cal_type == 'monthlyByDayR' ) {
+                   break;
+                 }
         default: $rep_str .= $cal_frequency; break;
       }
     }
@@ -330,14 +398,14 @@ if ( $res ) {
   dbi_free_result ( $res );
 }
 /* calculate end time */
-if ( $event_time > 0 && $row[5] > 0 )
+if ( $event_time >= 0 && $row[5] > 0 )
   $end_str = "-" . display_time ( add_duration ( $row[2], $row[5] ) );
 else
   $end_str = "";
 
 // get the email adress of the creator of the entry
 user_load_variables ( $create_by, "createby_" );
-$email_addr = $createby_email;
+$email_addr = empty ( $createby_email ) ? '' : $createby_email;
 
 // If confidential and not this user's event, then
 // They cannot seem name or description.
@@ -360,8 +428,10 @@ else
 
 // Get category Info
 if ( $categories_enabled == "Y" ) {
+  $cat_owner =  ( ( ! empty ( $user ) && strlen ( $user ) ) &&  ( $is_assistant  ||
+    $is_admin ) ) ? $user : $login;  
   $sql = "SELECT cat_name FROM webcal_categories, webcal_entry_user " .
-    "WHERE webcal_entry_user.cal_login = '$login' AND webcal_entry_user.cal_id = $id " .
+    "WHERE webcal_entry_user.cal_login = '$cat_owner' AND webcal_entry_user.cal_id = $id " .
     "AND webcal_entry_user.cal_category = webcal_categories.cat_id";
   $res2 = dbi_query ( $sql );
   if ( $res2 ) {
@@ -374,12 +444,20 @@ if ( $categories_enabled == "Y" ) {
 <h2><?php echo htmlspecialchars ( $name ); ?></h2>
 <table style="border-width:0px;">
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Description")?>:</td><td>
-	<?php
+ <?php etranslate("Description")?>:</td><td>
+ <?php
   if ( ! empty ( $allow_html_description ) &&
     $allow_html_description == 'Y' ) {
     $str = str_replace ( '&', '&amp;', $description );
-    echo str_replace ( '&amp;amp;', '&amp', $str );
+    $str = str_replace ( '&amp;amp;', '&amp;', $str );
+    // If there is no html found, then go ahead and replace
+    // the line breaks ("\n") with the html break.
+    if ( strstr ( $str, "<" ) && strstr ( $str, ">" ) ) {
+      // found some html...
+      echo $str;
+    } else {
+      echo nl2br ( activate_urls ( $str ) );
+    }
   } else {
     echo nl2br ( activate_urls ( htmlspecialchars ( $description ) ) );
   }
@@ -387,8 +465,8 @@ if ( $categories_enabled == "Y" ) {
 
 <?php if ( $event_status != 'A' && ! empty ( $event_status ) ) { ?>
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Status")?>:</td><td>
-	<?php
+ <?php etranslate("Status")?>:</td><td>
+ <?php
      if ( $event_status == 'W' )
        etranslate("Waiting for approval");
      if ( $event_status == 'D' )
@@ -400,76 +478,94 @@ if ( $categories_enabled == "Y" ) {
 <?php } ?>
 
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Date")?>:</td><td>
-	<?php
+ <?php etranslate("Date")?>:</td><td>
+ <?php
   if ( $event_repeats ) {
     echo date_to_str ( $event_date );
   } else {
-    echo date_to_str ( $row[1], "", true, false, $event_time );
+    echo date_to_str ( $row[1], "", true, false, ( $row[5] == ( 24 * 60 ) ? "" : $event_time ) );
   }
   ?>
 </td></tr>
 <?php if ( $event_repeats ) { ?>
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Repeat Type")?>:</td><td>
-	<?php echo date_to_str ( $row[1], "", true, false, $event_time ) . $rep_str; ?>
+ <?php etranslate("Repeat Type")?>:</td><td>
+ <?php echo date_to_str ( $row[1], "", true, false, $event_time ) . $rep_str; ?>
 </td></tr>
 <?php } ?>
 <?php if ( $event_time >= 0 ) { ?>
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Time")?>:</td><td>
-	<?php
-    if ( $row[5] == ( 24 * 60 ) )
+ <?php etranslate("Time")?>:</td><td>
+ <?php
+    if ( $row[5] == ( 24 * 60 ) ) {
       etranslate("All day event");
-    else
+    } else {
       echo display_time ( $row[2] ) . $end_str;
+    }
   ?>
 </td></tr>
 <?php } ?>
 <?php if ( $row[5] > 0 && $row[5] != ( 24 * 60 ) ) { ?>
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Duration")?>:</td><td>
-	<?php echo $row[5]; ?> <?php etranslate("minutes")?>
+ <?php etranslate("Duration")?>:</td><td>
+ <?php echo $row[5]; ?> <?php etranslate("minutes")?>
 </td></tr>
 <?php } ?>
 <?php if ( $disable_priority_field != "Y" ) { ?>
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Priority")?>:</td><td>
-	<?php echo $pri[$row[6]]; ?>
+ <?php etranslate("Priority")?>:</td><td>
+ <?php echo $pri[$row[6]]; ?>
 </td></tr>
 <?php } ?>
 <?php if ( $disable_access_field != "Y" ) { ?>
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Access")?>:</td><td>
-	<?php echo ( $row[8] == "P" ) ? translate("Public") : translate("Confidential"); ?>
+ <?php etranslate("Access")?>:</td><td>
+ <?php echo ( $row[8] == "P" ) ? translate("Public") : translate("Confidential"); ?>
 </td></tr>
 <?php } ?>
 <?php if ( $categories_enabled == "Y" && ! empty ( $category ) ) { ?>
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Category")?>:</td><td>
-	<?php echo $category; ?>
+ <?php etranslate("Category")?>:</td><td>
+ <?php echo $category; ?>
 </td></tr>
 <?php } ?>
 <?php
+// Display who originally created event
+// useful if assistant or Admin
+$proxy_fullname = '';  
+if ( !empty ( $DISPLAY_CREATED_BYPROXY ) && $DISPLAY_CREATED_BYPROXY == "Y" ) {
+  $res = dbi_query ( "SELECT wu.cal_firstname, wu.cal_lastname " .
+    "FROM webcal_user wu INNER JOIN webcal_entry_log wel ON wu.cal_login = wel.cal_login " .
+    "WHERE wel.cal_entry_id = $id " .
+    "AND wel.cal_type = 'C'" );
+  if ( $res ) {
+    $row3 = dbi_fetch_row ( $res ) ;
+   $proxy_fullname = $row3[0] . " " . $row3[1];
+   $proxy_fullname = ($createby_fullname == $proxy_fullname ? ""  :
+      " ( by " . $proxy_fullname . " )");
+  }
+}
+
 if ( $single_user == "N" ) {
   echo "<tr><td style=\"vertical-align:top; font-weight:bold;\">\n" . 
-	translate("Created by") . ":</td><td>\n";
-  if ( $is_private )
+ translate("Created by") . ":</td><td>\n";
+  if ( $is_private ) {
     echo "[" . translate("Confidential") . "]\n</td></tr>";
-  else {
-    if ( strlen ( $email_addr ) )
+  } else {
+    if ( strlen ( $email_addr ) ) {
       echo "<a href=\"mailto:$email_addr?subject=$subject\">" .
-        ( $row[0] == "__public__" ? "Public Access" : $createby_fullname ) .
-	"</a>\n</td></tr>";
-    else
-      echo ( $row[0] == "__public__" ? "Public Access" : $createby_fullname ) .
-	"\n</td></tr>";
+        ( $row[0] == "__public__" ? translate( "Public Access" ): $createby_fullname ) .
+        "</a>$proxy_fullname\n</td></tr>";
+    } else {
+      echo ( $row[0] == "__public__" ? translate( "Public Access" ) : $createby_fullname ) .
+        "$proxy_fullname\n</td></tr>";
+    }
   }
 }
 ?>
 <tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Updated")?>:</td><td>
-	<?php
+ <?php etranslate("Updated")?>:</td><td>
+ <?php
     echo date_to_str ( $row[3] );
     echo " ";
     echo display_time ( $row[4] );
@@ -488,26 +584,29 @@ for ( $i = 0; $i < count ( $site_extras ); $i++ ) {
       translate ( $site_extras[$i][1] ) .
       ":</td><td>\n";
     if ( $extra_type == $EXTRA_URL ) {
-      if ( strlen ( $extras[$extra_name]['cal_data'] ) )
+      if ( strlen ( $extras[$extra_name]['cal_data'] ) ) {
         echo "<a href=\"" . $extras[$extra_name]['cal_data'] . "\">" .
           $extras[$extra_name]['cal_data'] . "</a>\n";
+      }
     } else if ( $extra_type == $EXTRA_EMAIL ) {
-      if ( strlen ( $extras[$extra_name]['cal_data'] ) )
+      if ( strlen ( $extras[$extra_name]['cal_data'] ) ) {
         echo "<a href=\"mailto:" . $extras[$extra_name]['cal_data'] .
           "?subject=$subject\">" .
           $extras[$extra_name]['cal_data'] . "</a>\n";
+      }
     } else if ( $extra_type == $EXTRA_DATE ) {
-      if ( $extras[$extra_name]['cal_date'] > 0 )
+      if ( $extras[$extra_name]['cal_date'] > 0 ) {
         echo date_to_str ( $extras[$extra_name]['cal_date'] );
+      }
     } else if ( $extra_type == $EXTRA_TEXT ||
       $extra_type == $EXTRA_MULTILINETEXT ) {
       echo nl2br ( $extras[$extra_name]['cal_data'] );
     } else if ( $extra_type == $EXTRA_USER ) {
       echo $extras[$extra_name]['cal_data'];
     } else if ( $extra_type == $EXTRA_REMINDER ) {
-      if ( $extras[$extra_name]['cal_remind'] <= 0 )
+      if ( $extras[$extra_name]['cal_remind'] <= 0 ) {
         etranslate ( "No" );
-      else {
+      } else {
         etranslate ( "Yes" );
         if ( ( $extra_arg2 & $EXTRA_REMINDER_WITH_DATE ) > 0 ) {
           echo "&nbsp;&nbsp;-&nbsp;&nbsp;";
@@ -519,18 +618,21 @@ for ( $i = 0; $i < count ( $site_extras ); $i++ ) {
           $minutes -= ( $d * 24 * 60 );
           $h = (int) ( $minutes / 60 );
           $minutes -= ( $h * 60 );
-          if ( $d > 1 )
+          if ( $d > 1 ) {
             echo $d . " " . translate("days") . " ";
-	  else if ( $d == 1 )
-	    echo $d . " " . translate("day") . " ";
-          if ( $h > 1 )
+          } else if ( $d == 1 ) {
+            echo $d . " " . translate("day") . " ";
+          }
+          if ( $h > 1 ) {
             echo $h . " " . translate("hours") . " ";
-	  else if ( $h == 1 )
-	    echo $h . " " . translate("hour") . " ";
-          if ( $minutes > 1 )
+          } else if ( $h == 1 ) {
+            echo $h . " " . translate("hour") . " ";
+          }
+          if ( $minutes > 1 ) {
             echo $minutes . " " . translate("minutes");
-	  else if ( $minutes == 1 )
-	    echo $minutes . " " . translate("minute");
+          } else if ( $minutes == 1 ) {
+            echo $minutes . " " . translate("minute");
+          }
           echo " " . translate("before event" );
         }
       }
@@ -546,36 +648,39 @@ for ( $i = 0; $i < count ( $site_extras ); $i++ ) {
 // Only ask for participants if we are multi-user.
 $allmails = array ();
 $show_participants = ( $disable_participants_field != "Y" );
-if ( $is_admin )
+if ( $is_admin ) {
   $show_participants = true;
+}
 if ( $public_access == "Y" && $login == "__public__" &&
-  ( $public_access_others != "Y" || $public_access_view_part == "N" ) )
+  ( $public_access_others != "Y" || $public_access_view_part == "N" ) ) {
   $show_participants = false;
-if ( $single_user == "N" && $show_participants ) {
-?>
-<tr><td style="vertical-align:top; font-weight:bold;">
-	<?php etranslate("Participants")?>:</td><td>
-	<?php
+}
+if ( $single_user == "N" && $show_participants ) { ?>
+  <tr><td style="vertical-align:top; font-weight:bold;">
+  <?php etranslate("Participants")?>:</td><td>
+  <?php
   if ( $is_private ) {
     echo "[" . translate("Confidential") . "]";
   } else {
     $sql = "SELECT cal_login, cal_status FROM webcal_entry_user " .
       "WHERE cal_id = $id";
-    //echo "$sql<P>\n";
+    //echo "$sql\n";
     $res = dbi_query ( $sql );
     $first = 1;
     $num_app = $num_wait = $num_rej = 0;
     if ( $res ) {
       while ( $row = dbi_fetch_row ( $res ) ) {
         $pname = $row[0];
-        if ( $login == $row[0] && $row[1] == 'W' )
+        if ( $login == $row[0] && $row[1] == 'W' ) {
           $unapproved = TRUE;
-        if ( $row[1] == 'A' )
+        }
+        if ( $row[1] == 'A' ) {
           $approved[$num_app++] = $pname;
-        else if ( $row[1] == 'W' )
+        } else if ( $row[1] == 'W' ) {
           $waiting[$num_wait++] = $pname;
-        else if ( $row[1] == 'R' )
+        } else if ( $row[1] == 'R' )  {
           $rejected[$num_rej++] = $pname;
+        }
       }
       dbi_free_result ( $res );
     } else {
@@ -585,7 +690,8 @@ if ( $single_user == "N" && $show_participants ) {
   for ( $i = 0; $i < $num_app; $i++ ) {
     user_load_variables ( $approved[$i], "temp" );
     if ( strlen ( $tempemail ) ) {
-      echo "<a href=\"mailto:" . $tempemail . "?subject=$subject\">" . $tempfullname . "</a><br />\n";
+      echo "<a href=\"mailto:" . $tempemail . "?subject=$subject\">" . 
+        $tempfullname . "</a><br />\n";
       $allmails[] = $tempemail;
     } else {
       echo $tempfullname . "<br />\n";
@@ -597,15 +703,18 @@ if ( $single_user == "N" && $show_participants ) {
     $ext_users = explode ( "\n", $external_users );
     if ( is_array ( $ext_users ) ) {
       for ( $i = 0; $i < count( $ext_users ); $i++ ) {
-        if ( ! empty ( $ext_users[$i] ) )
-          echo $ext_users[$i] . " (" . translate("External User") . ")<br />\n";
+        if ( ! empty ( $ext_users[$i] ) ) {
+          echo $ext_users[$i] . " (" . translate("External User") . 
+            ")<br />\n";
+        }
       }
     }
   }
   for ( $i = 0; $i < $num_wait; $i++ ) {
     user_load_variables ( $waiting[$i], "temp" );
     if ( strlen ( $tempemail ) ) {
-      echo "<br /><a href=\"mailto:" . $tempemail . "?subject=$subject\">" . $tempfullname . "</a> (?)\n";
+      echo "<br /><a href=\"mailto:" . $tempemail . "?subject=$subject\">" . 
+        $tempfullname . "</a> (?)\n";
       $allmails[] = $tempemail;
     } else {
       echo "<br />" . $tempfullname . " (?)\n";
@@ -618,24 +727,29 @@ if ( $single_user == "N" && $show_participants ) {
         "?subject=$subject\">" . $tempfullname .
         "</a></strike> (" . translate("Rejected") . ")\n";
     } else {
-      echo "<br /><strike>$tempfullname</strike> (" . translate("Rejected") . ")\n";
+      echo "<br /><strike>$tempfullname</strike> (" . 
+        translate("Rejected") . ")\n";
     }
   }
 ?>
 </td></tr>
 <?php
-	} // end participants
+ } // end participants
 ?>
 
 </table>
 
-<p>
-<?php
+<br /><?php
+
+$rdate = "";
+if ( $event_repeats ) {
+  $rdate = "&amp;date=$event_date";
+}
 
 // Show a printer-friendly link
 if ( empty ( $friendly ) ) {
   echo "<a title=\"" . 
-    translate("Generate printer-friendly version") . "\" class=\"nav\" " .
+    translate("Generate printer-friendly version") . "\" class=\"printer\" " .
     "href=\"view_entry.php?id=$id&amp;friendly=1$rdate\" " .
     "target=\"cal_printer_friendly\">" .
     translate("Printer Friendly") . "</a><br />\n";
@@ -650,30 +764,33 @@ if ( empty ( $event_status ) ) {
 
 if ( $unapproved && $readonly == 'N' ) {
   echo "<a title=\"" . 
-	translate("Approve/Confirm entry") . "\" href=\"approve_entry.php?id=$id\" onclick=\"return confirm('" . 
-	translate("Approve this entry?") . "');\">" . 
-	translate("Approve/Confirm entry") . "</a><br />\n";
+    translate("Approve/Confirm entry") . 
+    "\" href=\"approve_entry.php?id=$id\" " .
+    "onclick=\"return confirm('" . 
+    translate("Approve this entry?") . "');\">" . 
+    translate("Approve/Confirm entry") . "</a><br />\n";
   echo "<a title=\"" . 
-	translate("Reject entry") . "\" href=\"reject_entry.php?id=$id\" onclick=\"return confirm('" .
-	translate("Reject this entry?") . "');\">" . 
-	translate("Reject entry") . "</a><br />\n";
+    translate("Reject entry") . "\" href=\"reject_entry.php?id=$id\" " .
+    "onclick=\"return confirm('" .
+    translate("Reject this entry?") . "');\">" . 
+    translate("Reject entry") . "</a><br />\n";
 }
 
-if ( ! empty ( $user ) && $login != $user )
+if ( ! empty ( $user ) && $login != $user ) {
   $u_url = "&amp;user=$user";
-else
+} else {
   $u_url = "";
+}
 
-$can_edit = ( $is_admin || $is_nonuser_admin && ($user == $create_by) || ( $is_assistant && ! $is_private && ($user == $create_by) ) ||
+$can_edit = ( $is_admin || $is_nonuser_admin && ($user == $create_by) || 
+  ( $is_assistant && ! $is_private && ($user == $create_by) ) ||
   ( $readonly != "Y" && ( $login == $create_by || $single_user == "Y" ) ) );
-if ( $public_access == "Y" && $login == "__public__" )
+if ( $public_access == "Y" && $login == "__public__" ) {
   $can_edit = false;
-if ( $readonly == 'Y' )
+}
+if ( $readonly == 'Y' ) {
   $can_edit = false;
-
-$rdate = "";
-if ( $event_repeats )
-  $rdate = "&amp;date=$event_date";
+}
 
 // If approved, but event category not set (and user does not have permission
 // to edit where they could also set the category), then allow them to
@@ -682,70 +799,86 @@ if ( empty ( $user ) && $categories_enabled == "Y" &&
   $readonly != "Y" && $is_my_event && $login != "__public__" &&
   $event_status != "D" && ! $can_edit )  {
   echo "<a title=\"" . 
-	translate("Set category") . "\" class=\"nav\" href=\"set_entry_cat.php?id=$id$rdate\">" .
-	translate("Set category") . "</a><br />\n";
+    translate("Set category") . "\" class=\"nav\" " .
+    "href=\"set_entry_cat.php?id=$id$rdate\">" .
+    translate("Set category") . "</a><br />\n";
 }
 
 if ( $can_edit && $event_status != "D" ) {
   if ( $event_repeats ) {
     echo "<a title=\"" .
-	translate("Edit repeating entry for all dates") . "\" class=\"nav\" href=\"edit_entry.php?id=$id$u_url\">" . 
-	translate("Edit repeating entry for all dates") . "</a><br />\n";
+      translate("Edit repeating entry for all dates") . 
+      "\" class=\"nav\" href=\"edit_entry.php?id=$id$u_url\">" . 
+      translate("Edit repeating entry for all dates") . "</a><br />\n";
     // Don't allow override of first event
-    if ( ! empty ( $date ) && $date != $orig_date )
+    if ( ! empty ( $date ) && $date != $orig_date ) {
       echo "<a title=\"" .
-	translate("Edit entry for this date") . "\" class=\"nav\" href=\"edit_entry.php?id=$id$u_url$rdate&amp;override=1\">" .
-	translate("Edit entry for this date") . "</a><br />\n";
+        translate("Edit entry for this date") . "\" class=\"nav\" " . 
+        "href=\"edit_entry.php?id=$id$u_url$rdate&amp;override=1\">" .
+        translate("Edit entry for this date") . "</a><br />\n";
+    }
     echo "<a title=\"" . 
-	translate("Delete repeating event for all dates") . "\" class=\"nav\" href=\"del_entry.php?id=$id$u_url&amp;override=1\" onclick=\"return confirm('" . 
-	translate("Are you sure you want to delete this entry?") . "\\n\\n" . 
-	translate("This will delete this entry for all users.") . "');\">" . 
-	translate("Delete repeating event for all dates") . "</a><br />\n";
+      translate("Delete repeating event for all dates") . 
+      "\" class=\"nav\" href=\"del_entry.php?id=$id$u_url&amp;override=1\" " .
+      "onclick=\"return confirm('" . 
+      translate("Are you sure you want to delete this entry?") . "\\n\\n" . 
+      translate("This will delete this entry for all users.") . "');\">" . 
+      translate("Delete repeating event for all dates") . "</a><br />\n";
     // Don't allow deletion of first event
-    if ( ! empty ( $date ) && $date != $orig_date )
+    if ( ! empty ( $date ) && $date != $orig_date ) {
       echo "<a title=\"" . 
-	translate("Delete entry only for this date") . "\" class=\"nav\" href=\"del_entry.php?id=$id$u_url$rdate&amp;override=1\" onclick=\"return confirm('" .
-	translate("Are you sure you want to delete this entry?") . "\\n\\n" . 
-	translate("This will delete this entry for all users.") . "');\">" . 
-	translate("Delete entry only for this date") . "</a><br />\n";
+        translate("Delete entry only for this date") . 
+        "\" class=\"nav\" href=\"del_entry.php?id=$id$u_url$rdate&amp;override=1\" " .
+        "onclick=\"return confirm('" .
+        translate("Are you sure you want to delete this entry?") . "\\n\\n" . 
+        translate("This will delete this entry for all users.") . "');\">" . 
+        translate("Delete entry only for this date") . "</a><br />\n";
+    }
   } else {
     echo "<a title=\"" .
-      translate("Edit entry") . "\" class=\"nav\" href=\"edit_entry.php?id=$id$u_url\">" .
+      translate("Edit entry") . "\" class=\"nav\" " .
+      "href=\"edit_entry.php?id=$id$u_url\">" .
       translate("Edit entry") . "</a><br />\n";
     echo "<a title=\"" . 
-	translate("Delete entry") . "\" class=\"nav\" href=\"del_entry.php?id=$id$u_url$rdate\" onclick=\"return confirm('" . 
-	translate("Are you sure you want to delete this entry?") . "\\n\\n" . 
-	translate("This will delete this entry for all users.") . "');\">" . 
-	translate("Delete entry") . "</a><br />\n";
+      translate("Delete entry") . "\" class=\"nav\" " .
+      "href=\"del_entry.php?id=$id$u_url$rdate\" onclick=\"return confirm('" . 
+       translate("Are you sure you want to delete this entry?") . "\\n\\n" . 
+       translate("This will delete this entry for all users.") . "');\">" . 
+       translate("Delete entry") . "</a><br />\n";
   }
   echo "<a title=\"" . 
-	translate("Copy entry") . "\" class=\"nav\" href=\"edit_entry.php?id=$id$u_url&amp;copy=1\">" . 
-	translate("Copy entry") . "</a><br />\n";  
+    translate("Copy entry") . "\" class=\"nav\" " .
+    "href=\"edit_entry.php?id=$id$u_url&amp;copy=1\">" . 
+    translate("Copy entry") . "</a><br />\n";  
 } elseif ( $readonly != "Y" && $is_my_event && $login != "__public__" &&
   $event_status != "D" )  {
   echo "<a title=\"" . 
-	translate("Delete entry") . "\" class=\"nav\" href=\"del_entry.php?id=$id$u_url$rdate\" onclick=\"return confirm('" . 
-	translate("Are you sure you want to delete this entry?") . "\\n\\n" . 
-	translate("This will delete the entry from your calendar.") . "');\">" . 
-	translate("Delete entry") . "</a><br />\n";
+    translate("Delete entry") . "\" class=\"nav\" " .
+    "href=\"del_entry.php?id=$id$u_url$rdate\" onclick=\"return confirm('" . 
+    translate("Are you sure you want to delete this entry?") . "\\n\\n" . 
+    translate("This will delete the entry from your calendar.") . "');\">" . 
+    translate("Delete entry") . "</a><br />\n";
   echo "<a title=\"" . 
-	translate("Copy entry") . "\" class=\"nav\" href=\"edit_entry.php?id=$id&amp;copy=1\">" . 
-	translate("Copy entry") . "</a><br />\n";
+    translate("Copy entry") . "\" class=\"nav\" " .
+    "href=\"edit_entry.php?id=$id&amp;copy=1\">" . 
+    translate("Copy entry") . "</a><br />\n";
 }
 if ( $readonly != "Y" && ! $is_my_event && ! $is_private && 
   $event_status != "D" && $login != "__public__" )  {
   echo "<a title=\"" . 
-	translate("Add to My Calendar") . "\" class=\"nav\" href=\"add_entry.php?id=$id\" onclick=\"return confirm('" . 
-	translate("Do you want to add this entry to your calendar?") . "\\n\\n" . 
-	translate("This will add the entry to your calendar.") . "');\">" . 
-	translate("Add to My Calendar") . "</a><br />\n";
+    translate("Add to My Calendar") . "\" class=\"nav\" " .
+    "href=\"add_entry.php?id=$id\" onclick=\"return confirm('" . 
+    translate("Do you want to add this entry to your calendar?") . "\\n\\n" . 
+    translate("This will add the entry to your calendar.") . "');\">" . 
+    translate("Add to My Calendar") . "</a><br />\n";
 }
 
 if ( count ( $allmails ) > 0 ) {
   echo "<a title=\"" . 
-	translate("Email all participants") . "\" class=\"nav\" href=\"mailto:" . implode ( ",", $allmails ) .
+    translate("Email all participants") . "\" class=\"nav\" " .
+    "href=\"mailto:" . implode ( ",", $allmails ) .
     "?subject=" . rawurlencode($subject) . "\">" . 
-	translate("Email all participants") . "</a><br />\n";
+    translate("Email all participants") . "</a><br />\n";
 }
 
 $show_log = false;
@@ -753,12 +886,14 @@ $show_log = false;
 if ( $is_admin ) {
   if ( empty ( $log ) ) {
     echo "<a title=\"" . 
-	translate("Show activity log") . "\" class=\"nav\" href=\"view_entry.php?id=$id&amp;log=1\">" . 
-	translate("Show activity log") . "</a><br />\n";
+      translate("Show activity log") . "\" class=\"nav\" " .
+      "href=\"view_entry.php?id=$id&amp;log=1\">" . 
+      translate("Show activity log") . "</a><br />\n";
   } else {
     echo "<a title=\"" . 
-	translate("Hide activity log") . "\" class=\"nav\" href=\"view_entry.php?id=$id\">" . 
-	translate("Hide activity log") . "</a><br />\n";
+      translate("Hide activity log") . "\" class=\"nav\" " .
+      "href=\"view_entry.php?id=$id\">" . 
+       translate("Hide activity log") . "</a><br />\n";
     $show_log = true;
   }
 }
@@ -766,10 +901,13 @@ if ( $is_admin ) {
 if ( $show_log ) {
   echo "<h3>" . translate("Activity Log") . "</h3>\n";
   echo "<table class=\"embactlog\">\n";
-  echo "<tr><th class=\"usr\">\n" . translate("User") . "</th><th class=\"cal\">\n";
+  echo "<tr><th class=\"usr\">\n";
+  echo translate("User") . "</th><th class=\"cal\">\n";
   echo translate("Calendar") . "</th><th class=\"date\">\n";
-  echo translate("Date") . "/" . translate("Time") . "</th><th class=\"action\">\n";
+  echo translate("Date") . "/" . 
+   translate("Time") . "</th><th class=\"action\">\n";
   echo translate("Action") . "\n</th></tr>\n";
+
   $res = dbi_query ( "SELECT cal_login, cal_user_cal, cal_type, " .
     "cal_date, cal_time " .
     "FROM webcal_entry_log WHERE cal_entry_id = $id " .
@@ -779,22 +917,23 @@ if ( $show_log ) {
       echo "<tr><td>\n";
       echo $row[0] . "</td><td>\n";
       echo $row[1] . "</td><td>\n" . 
-	date_to_str ( $row[3] ) . "&nbsp;" .
+        date_to_str ( $row[3] ) . "&nbsp;" .
         display_time ( $row[4] ) . "</td><td>\n";
-      if ( $row[2] == $LOG_CREATE )
+      if ( $row[2] == $LOG_CREATE ) {
         etranslate("Event created");
-      else if ( $row[2] == $LOG_APPROVE )
+      } else if ( $row[2] == $LOG_APPROVE ) {
         etranslate("Event approved");
-      else if ( $row[2] == $LOG_REJECT )
+      } else if ( $row[2] == $LOG_REJECT ) {
         etranslate("Event rejected");
-      else if ( $row[2] == $LOG_UPDATE )
+      } else if ( $row[2] == $LOG_UPDATE ) {
         etranslate("Event updated");
-      else if ( $row[2] == $LOG_DELETE )
+      } else if ( $row[2] == $LOG_DELETE ) {
         etranslate("Event deleted");
-      else if ( $row[2] == $LOG_NOTIFICATION )
+      } else if ( $row[2] == $LOG_NOTIFICATION ) {
         etranslate("Notification sent");
-      else if ( $row[2] == $LOG_REMINDER )
+      } else if ( $row[2] == $LOG_REMINDER ) {
         etranslate("Reminder sent");
+      }
       echo "</td></tr>\n";
     }
     dbi_free_result ( $res );
@@ -803,30 +942,27 @@ if ( $show_log ) {
 }
 
 if (! $is_private) {
-  echo "<br /><form method=\"post\" name=\"exportform\" action=\"export_handler.php\">\n";
-  echo "<strong>";
-  etranslate("Export this entry to");
-  echo ":</strong>\n";
-  echo "<select name=\"format\">\n";
-  echo "<option value=\"ical\">iCalendar</option>\n";
-  echo "<option value=\"vcal\">vCalendar</option>\n";
-  echo "<option value=\"pilot-csv\">pilot-datebook CSV (";
-  etranslate("Palm Pilot");
-  echo ")</option>\n";
-  echo "<option value=\"pilot-text\">install-datebook (";
-  etranslate("Palm Pilot");
-  echo ")</option>\n";
+  echo "<br /><form method=\"post\" name=\"exportform\" " .
+    "action=\"export_handler.php\">\n";
+  echo "<label for=\"exformat\">" . 
+    translate("Export this entry to") . ":&nbsp;</label>\n";
+  echo "<select name=\"format\" id=\"exformat\">\n";
+  echo " <option value=\"ical\">iCalendar</option>\n";
+  echo " <option value=\"vcal\">vCalendar</option>\n";
+  echo " <option value=\"pilot-csv\">Pilot-datebook CSV (" . 
+    translate("Palm Pilot") . ")</option>\n";
+  echo " <option value=\"pilot-text\">Install-datebook (" . 
+    translate("Palm Pilot") . ")</option>\n";
   echo "</select>\n";
   echo "<input type=\"hidden\" name=\"id\" value=\"$id\" />\n";
-  echo "<input type=\"submit\" value=\"";
-  etranslate("Export");
-  echo "\" />\n";
+  echo "<input type=\"submit\" value=\"" . 
+    translate("Export") . "\" />\n";
   echo "</form>\n";
 }
 ?>
 
 <?php
-  print_trailer ( empty ( $friendly ) );
+ print_trailer ( empty ($friendly) );
 ?>
 </body>
 </html>
